{% load spellbook_tags %}
{% load static %}
<link rel="stylesheet" href="{% static 'django_spellbook/css_modules/sidebar_toc.css' %}">
<div class="toc-wrapper toc-no-transition toc-mobile-border">
    {% if toc.children %}
        <ul class="toc-list">
            {% include "django_spellbook/recursive/_toc_sidebar.html" with items=toc.children %}
        </ul>
    {% endif %}
</div>
<script type="module" src="{% static 'django_spellbook/js/toc.mjs' %}"></script>
