{% extends "django_spellbook/bases/sidebar_left.html" %}
{% load spellbook_tags %}

{% block spellbook_md %}
    <div class="sb-directory-index">
        {% include "django_spellbook/directory_index/listing.html" %}
    </div>
{% endblock %}
